#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-hspec
version:              1.2.0.4
visibility:           public
id:                   tasty-hspec-1.2.0.4-AAjcFM0mPjL4r0dLmFNoDd
key:                  tasty-hspec-1.2.0.4-AAjcFM0mPjL4r0dLmFNoDd
license:              BSD-3-Clause
maintainer:           mitchellwrosen@gmail.com
author:               Mitchell Rosen
homepage:             https://github.com/mitchellwrosen/tasty-hspec
synopsis:             Hspec support for the Tasty test framework.
description:
    This package provides a Tasty provider for Hspec test
    suites.

category:             Testing
abi:                  5fd48be11531de98217bf60dfa535929
exposed:              True
exposed-modules:      Test.Tasty.Hspec
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tasty-hspec-1.2.0.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tasty-hspec-1.2.0.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tasty-hspec-1.2.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-hspec
hs-libraries:         HStasty-hspec-1.2.0.4-AAjcFM0mPjL4r0dLmFNoDd
depends:
    QuickCheck-2.15.0.1-K0JFHgomBHu3hU8T85EWwT base-4.18.2.1
    hspec-2.11.7-3Kp3PTiLFy0JhU2sO60TrZ
    hspec-api-2.11.7-5QLvr44NtF4K1prHHUK7bC
    hspec-core-2.11.7-7fX3F8gLgA3T5SWesER1k
    tasty-1.5.3-4Cw0W10idvOIHvdgaqPCw
    tasty-quickcheck-0.11.1-KzDxkNqEiN5AKB7c67cIu
    tasty-smallcheck-0.8.2-5vHRZMMK4Z7EKtJozDFc4k

haddock-interfaces:   /usr/share/doc/haskell-tasty-hspec/html/tasty-hspec.haddock
haddock-html:         /usr/share/doc/haskell-tasty-hspec/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

